@@ -13,6 +13,7 @@ from fps_auth.config import get_auth_config  # type: ignore
 
 from fps_lab.routes import init_router  # type: ignore
 from fps_lab.config import get_lab_config  # type: ignore
+from fps_lab.utils import get_federated_extensions  # type: ignore
 
 router = APIRouter()
 prefix_dir, federated_extensions = init_router(router, "retro/tree")
@@ -40,7 +41,7 @@ retro_federated_extensions = [
         "name": "@retrolab/lab-extension",
         "style": "./style",
     }
-] + federated_extensions
+]
 
 
 @router.get("/retro/tree", response_class=HTMLResponse)
@@ -50,34 +51,34 @@ async def get_tree(
     return get_index("Tree", "tree", auth_config.collaborative, lab_config.base_url)
 
 
-@router.get("/retro/notebooks/{name}", response_class=HTMLResponse)
+@router.get("/retro/notebooks/{path:path}", response_class=HTMLResponse)
 async def get_notebook(
-    name: str,
+    path,
     user: User = Depends(current_user),
     lab_config=Depends(get_lab_config),
     auth_config=Depends(get_auth_config),
 ):
-    return get_index(name, "notebooks", auth_config.collaborative, lab_config.base_url)
+    return get_index(path, "notebooks", auth_config.collaborative, lab_config.base_url)
 
 
-@router.get("/retro/edit/{name}", response_class=HTMLResponse)
+@router.get("/retro/edit/{path:path}", response_class=HTMLResponse)
 async def edit_file(
-    name: str,
+    path,
     user: User = Depends(current_user),
     lab_config=Depends(get_lab_config),
     auth_config=Depends(get_auth_config),
 ):
-    return get_index(name, "edit", auth_config.collaborative, lab_config.base_url)
+    return get_index(path, "edit", auth_config.collaborative, lab_config.base_url)
 
 
-@router.get("/retro/consoles/{name}", response_class=HTMLResponse)
+@router.get("/retro/consoles/{path:path}", response_class=HTMLResponse)
 async def get_console(
-    name: str,
+    patn,
     user: User = Depends(current_user),
     lab_config=Depends(get_lab_config),
     auth_config=Depends(get_auth_config),
 ):
-    return get_index(name, "consoles", auth_config.collaborative, lab_config.base_url)
+    return get_index(path, "consoles", auth_config.collaborative, lab_config.base_url)
 
 
 @router.get("/retro/terminals/{name}", response_class=HTMLResponse)
@@ -91,6 +92,8 @@ async def get_terminal(
 
 
 def get_index(doc_name, retro_page, collaborative, base_url="/"):
+    extensions_dir = prefix_dir / "share" / "jupyter" / "labextensions"
+    federated_extensions, disabled_extension = get_federated_extensions(extensions_dir)
     page_config = {
         "appName": "RetroLab",
         "appNamespace": "retro",
@@ -100,9 +103,9 @@ def get_index(doc_name, retro_page, collaborative, base_url="/"):
         "baseUrl": base_url,
         "cacheFiles": True,
         "collaborative": collaborative,
-        "disabledExtensions": [],
+        "disabledExtensions": disabled_extension,
         "extraLabextensionsPath": [],
-        "federated_extensions": retro_federated_extensions,
+        "federated_extensions": retro_federated_extensions + federated_extensions,
         "frontendUrl": "/retro/",
         "fullAppUrl": f"{base_url}lab",
         "fullLabextensionsUrl": f"{base_url}lab/extensions",
